@@ -1,5 +1,4 @@
-package # hide from PAUSE
-    DBIx::Class::CDBICompat::ObjIndexStubs;
+package DBIx::Class::CDBICompat::ObjIndexStubs;
 
 use strict;
 use warnings;
