@@ -10,7 +10,7 @@ __PACKAGE__->load_components(qw/PK::Auto/);
 sub last_insert_id {
   my $self = shift;
   $self->get_autoinc_seq unless $self->{_autoinc_seq};
-  $self->storage->dbh->last_insert_id(undef,undef,undef,undef,
+  $self->result_source->storage->dbh->last_insert_id(undef,undef,undef,undef,
     {sequence=>$self->{_autoinc_seq}});
 }
 
@@ -22,8 +22,8 @@ sub get_autoinc_seq {
     return $self->{_autoinc_seq} = $self->sequence;
   }
   
-  my @pri = keys %{ $self->_primaries };
-  my $dbh = $self->storage->dbh;
+  my @pri = $self->primary_columns;
+  my $dbh = $self->result_source->storage->dbh;
   while (my $col = shift @pri) {
     my $info = $dbh->column_info(undef,undef,$self->table,$col)->fetchrow_arrayref;
     if (defined $info->[12] and $info->[12] =~ 
@@ -39,13 +39,17 @@ sub get_autoinc_seq {
 
 =head1 NAME 
 
-DBIx::Class::PK::Auto::Pg - Automatic Primary Key class for Postgresql
+DBIx::Class::PK::Auto::Pg - Automatic primary key class for PostgreSQL
 
 =head1 SYNOPSIS
 
+  # In your table classes
+  __PACKAGE__->load_components(qw/PK::Auto::Pg Core/);
+  __PACKAGE__->set_primary_key('id');
+
 =head1 DESCRIPTION
 
-This class implements autoincrements for Postgresql.
+This class implements autoincrements for PostgreSQL.
 
 =head1 AUTHORS
 
@@ -56,4 +60,3 @@ Marcus Ramberg <m.ramberg@cpan.org>
 You may distribute this code under the same terms as Perl itself.
 
 =cut
-
