@@ -1,26 +1,30 @@
 use strict;
 use warnings;
-use DBICTest;
+use DBICTest::Schema;
 
-my $schema = DBICTest->initialise;
+my $db_file = "t/var/DBIxClass.db";
+
+unlink($db_file) if -e $db_file;
+unlink($db_file . "-journal") if -e $db_file . "-journal";
+mkdir("t/var") unless -d "t/var";
+
+my $dsn = "dbi:SQLite:${db_file}";
+
+my $schema = DBICTest::Schema->compose_connection('DBICTest' => $dsn);
 
 $schema->storage->on_connect_do([ "PRAGMA synchronous = OFF" ]);
 
 my $dbh = $schema->storage->dbh;
 
-if ($ENV{"DBICTEST_SQLT_DEPLOY"}) {
-  $schema->deploy;
-} else {
-  open IN, "t/lib/sqlite.sql";
+open IN, "t/lib/sqlite.sql";
 
-  my $sql;
+my $sql;
 
-  { local $/ = undef; $sql = <IN>; }
+{ local $/ = undef; $sql = <IN>; }
 
-  close IN;
+close IN;
 
-  $dbh->do($_) for split(/\n\n/, $sql);
-}
+$dbh->do($_) for split(/\n\n/, $sql);
 
 $schema->storage->dbh->do("PRAGMA synchronous = OFF");
 
@@ -110,12 +114,4 @@ $schema->populate('CD_to_Producer', [
   [ 1, 3 ],
 ]);
 
-$schema->populate('TreeLike', [
-  [ qw/id parent name/ ],
-  [ 1, 0, 'foo'  ],
-  [ 2, 1, 'bar'  ],
-  [ 3, 2, 'baz'  ],
-  [ 4, 3, 'quux' ],
-]);
-
 1;
